@@ -8,7 +8,7 @@
  * 
  * Further details on the project are available at http://postfixadmin.sf.net 
  * 
- * @version $Id: config.inc.php 1833 2016-04-11 23:54:34Z christian_boltz $ 
+ * @version $Id$ 
  * @license GNU GPL v2 or later. 
  * 
  * File: config.inc.php
@@ -137,7 +137,7 @@ $CONF['smtp_client'] = '';
 // system = whatever you have set as your PHP system default
 // cleartext = clear text passwords (ouch!)
 // mysql_encrypt = useful for PAM integration
-// authlib = support for courier-authlib style passwords
+// authlib = support for courier-authlib style passwords - also set $CONF['authlib_default_flavor']
 // dovecot:CRYPT-METHOD = use dovecotpw -s 'CRYPT-METHOD'. Example: dovecot:CRAM-MD5
 //     IMPORTANT:
 //     - don't use dovecot:* methods that include the username in the hash - you won't be able to login to PostfixAdmin in this case
@@ -146,6 +146,7 @@ $CONF['smtp_client'] = '';
 $CONF['encrypt'] = 'md5crypt';
 
 // In what flavor should courier-authlib style passwords be encrypted?
+// (only used if $CONF['encrypt'] == 'authlib')
 // md5 = {md5} + base64 encoded md5 hash
 // md5raw = {md5raw} + plain encoded md5 hash
 // SHA = {SHA} + base64-encoded sha1 hash
@@ -157,6 +158,9 @@ $CONF['authlib_default_flavor'] = 'md5raw';
 // $CONF['dovecotpw'] = "/usr/sbin/dovecotpw";
 // for dovecot 2.x (dovecot 2.0.0 - 2.0.7 is not supported!)
 $CONF['dovecotpw'] = "/usr/sbin/doveadm pw";
+if(file_exists('/usr/bin/doveadm')) {
+    $CONF['dovecotpw'] = "/usr/bin/doveadm pw"; # debian
+}
 
 // Password validation
 // New/changed passwords will be validated using all regular expressions in the array.
@@ -261,7 +265,7 @@ function maildir_name_hook($domain, $user) {
     PostfixAdmin, but it does not create it in the database. You have to do
     that yourself. 
     Please follow the naming policy for custom database fields and tables on
-    http://sourceforge.net/apps/mediawiki/postfixadmin/index.php?title=Custom_fields
+    https://sourceforge.net/p/postfixadmin/wiki/Custom_fields/
     to avoid clashes with future versions of PostfixAdmin.
 
     See initStruct() in the *Handler class for the default $struct.
@@ -395,6 +399,9 @@ $CONF['backup'] = 'NO';
 // Send Mail
 // If you don't want sendmail tab set this to 'NO';
 $CONF['sendmail'] = 'YES';
+// Set this to YES if you want to allow non-super-admins to
+// send mails to their users
+$CONF['sendmail_all_admins'] = 'NO';
 
 // Logging
 // If you don't want logging set this to 'NO';
@@ -560,7 +567,7 @@ $CONF['new_quota_table'] = 'YES';
 // $CONF['create_mailbox_subdirs_hostoptions']=array('novalidate-cert','norsh');
 // See also the "Optional flags for names" table at
 // http://www.php.net/manual/en/function.imap-open.php
-$CONF['create_mailbox_subdirs_hostoptions'] = array('');
+$CONF['create_mailbox_subdirs_hostoptions'] = array();
 
 
 // Theme Config
@@ -582,7 +589,7 @@ $CONF['xmlrpc_enabled'] = false;
 // file (config.local.php) instead of editing this file and override some
 // settings there.
 if (file_exists(dirname(__FILE__) . '/config.local.php')) {
-    include_once(dirname(__FILE__) . '/config.local.php');
+    require_once(dirname(__FILE__) . '/config.local.php');
 }
 
 //
