@@ -8,7 +8,7 @@
  * 
  * Further details on the project are available at http://postfixadmin.sf.net 
  * 
- * @version $Id: list-virtual.php 1822 2015-12-06 23:27:45Z christian_boltz $ 
+ * @version $Id$ 
  * @license GNU GPL v2 or later. 
  * 
  * File: list-virtual.php
@@ -136,10 +136,9 @@ $table_alias = table_by_key('alias');
 $table_mailbox = table_by_key('mailbox');
 
 if (count($search) == 0 || !isset($search['_'])) {
-    $list_param = "domain='$fDomain'";
+    $search_alias = array('domain' => $fDomain);
 } else {
-    $searchterm = escape_string($search['_']);
-    $list_param = "(address LIKE '%$searchterm%' OR goto LIKE '%$searchterm%')";
+    $search_alias = array('_' => $search['_']);
 }
 
 $handler = new AliasHandler(0, $admin_username);
@@ -153,8 +152,8 @@ $alias_data['struct']['goto_mailbox']['display_in_list'] = 0; # not useful/defin
 $alias_data['struct']['on_vacation']['display_in_list'] = 0;
 $alias_data['msg']['show_simple_search'] = False; # hide search box
 
-$handler->getList($list_param, array(), $page_size, $fDisplay);
-$pagebrowser_alias = $handler->getPagebrowser($list_param, array());
+$handler->getList($search_alias, array(), $page_size, $fDisplay);
+$pagebrowser_alias = $handler->getPagebrowser($search_alias, array());
 $tAlias = $handler->result();
 
 
@@ -213,17 +212,18 @@ $query = "$sql_select\n$mailbox_pagebrowser_query\n$sql_limit";
 
 $result = db_query ($query);
 
+$tMailbox = array();
+
 if ($result['rows'] > 0) {
     $delimiter = preg_quote($CONF['recipient_delimiter'], "/");
     $goto_single_rec_del = "";
 
-    $tMailbox = array();
     while ($row = db_array ($result['result'])) {
         if ($display_mailbox_aliases) {
             $goto_split = explode(",", $row['goto']);
             $row['goto_mailbox'] = 0;
             $row['goto_other'] = array();
-            
+
             foreach ($goto_split as $goto_single) {
                 if (!empty($CONF['recipient_delimiter'])) {
                     $goto_single_rec_del = preg_replace('/' .$delimiter. '[^' .$delimiter. '@]*@/', "@", $goto_single);
@@ -325,12 +325,16 @@ if ((is_array ($tMailbox) and sizeof ($tMailbox) > 0)) {
 
 class cNav_bar
 {
-    var $count, $title, $limit, $page_size, $pages, $search; //* arguments
-    var $url; //* manually
-    var $fInit, $arr_prev, $arr_next, $arr_top; //* internal
-    var $anchor;
+    protected $count, $title, $limit, $page_size, $pages, $search; //* arguments
 
-    function cNav_bar ($aTitle, $aLimit, $aPage_size, $aPages, $aSearch) {
+    /* @var string - appended to page link href */
+    public $append_to_url = '';
+
+    protected $have_run_init = false;
+    protected $arr_prev, $arr_next, $arr_top; //* internal
+    protected $anchor;
+
+    public function __construct ($aTitle, $aLimit, $aPage_size, $aPages, $aSearch) {
         $this->count = count($aPages);
         $this->title = $aTitle;
         $this->limit = $aLimit;
@@ -341,20 +345,18 @@ class cNav_bar
         } else {
             $this->search = "";
         }
-        $this->url = '';
-        $this->fInit = false;
     }
 
-    function init () {
+    private function init () {
         $this->anchor = 'a'.substr ($this->title, 3);
-        $this->url .= '#'.$this->anchor;
-        ($this->limit >= $this->page_size) ? $this->arr_prev = '&nbsp;<a href="?limit='.($this->limit - $this->page_size).$this->search.$this->url.'"><img border="0" src="images/arrow-l.png" title="'.$GLOBALS ['PALANG']['pOverview_left_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_left_arrow'].'"/></a>&nbsp;' : $this->arr_prev = '';
-        ($this->limit > 0) ? $this->arr_top = '&nbsp;<a href="?limit=0' .$this->search.$this->url.'"><img border="0" src="images/arrow-u.png" title="'.$GLOBALS ['PALANG']['pOverview_up_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_up_arrow'].'"/></a>&nbsp;' : $this->arr_top = '';
-        (($this->limit + $this->page_size) < ($this->count * $this->page_size)) ? $this->arr_next = '&nbsp;<a href="?limit='.($this->limit + $this->page_size).$this->search.$this->url.'"><img border="0" src="images/arrow-r.png" title="'.$GLOBALS ['PALANG']['pOverview_right_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_right_arrow'].'"/></a>&nbsp;' : $this->arr_next = '';
-        $this->fInit = true;
+        $this->append_to_url .= '#'.$this->anchor;
+        ($this->limit >= $this->page_size) ? $this->arr_prev = '&nbsp;<a href="?limit='.($this->limit - $this->page_size).$this->search.$this->append_to_url.'"><img border="0" src="images/arrow-l.png" title="'.$GLOBALS ['PALANG']['pOverview_left_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_left_arrow'].'"/></a>&nbsp;' : $this->arr_prev = '';
+        ($this->limit > 0) ? $this->arr_top = '&nbsp;<a href="?limit=0' .$this->search.$this->append_to_url.'"><img border="0" src="images/arrow-u.png" title="'.$GLOBALS ['PALANG']['pOverview_up_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_up_arrow'].'"/></a>&nbsp;' : $this->arr_top = '';
+        (($this->limit + $this->page_size) < ($this->count * $this->page_size)) ? $this->arr_next = '&nbsp;<a href="?limit='.($this->limit + $this->page_size).$this->search.$this->append_to_url.'"><img border="0" src="images/arrow-r.png" title="'.$GLOBALS ['PALANG']['pOverview_right_arrow'].'" alt="'.$GLOBALS ['PALANG']['pOverview_right_arrow'].'"/></a>&nbsp;' : $this->arr_next = '';
+        $this->have_run_init = true;
     }
 
-    function display_pre () {
+    private function display_pre() {
         $ret_val = '<div class="nav_bar"';
         //$ret_val .= ' style="background-color:#ffa;"';
         $ret_val .= '>';
@@ -363,16 +365,16 @@ class cNav_bar
         return $ret_val;
     }
 
-    function display_post () {
+    private function display_post() {
         $ret_val = '</td></tr></table></div>';
         return $ret_val;
     }
 
-    function display_top () {
+    public function display_top() {
         $ret_val = '';
         if ($this->count < 1)
             return $ret_val;
-        if (!$this->fInit)
+        if (!$this->have_run_init)
             $this->init ();
             
         $ret_val .= '<a name="'.$this->anchor.'"></a>';
@@ -386,7 +388,7 @@ class cNav_bar
             if ($i == $highlight_at) {
                 $ret_val .= '<b>'.$lPage.'</b>'."\n";
             } else {
-                $ret_val .= '<a href="?limit='.($i * $this->page_size).$this->search.$this->url.'">'.$lPage.'</a>'."\n";
+                $ret_val .= '<a href="?limit='.($i * $this->page_size).$this->search.$this->append_to_url.'">'.$lPage.'</a>'."\n";
             }
         }
         $ret_val .= '</td><td valign="middle" align="right">';
@@ -395,15 +397,15 @@ class cNav_bar
         $ret_val .= $this->arr_top;
         $ret_val .= $this->arr_next;
 
-        $ret_val .= $this->display_post ();
+        $ret_val .= $this->display_post();
         return $ret_val;
     }
 
-    function display_bottom () {
+    public function display_bottom() {
         $ret_val = '';
         if ($this->count < 1)
             return $ret_val;
-        if (!$this->fInit)
+        if (!$this->have_run_init)
             $this->init ();
         $ret_val .= $this->display_pre ();
         $ret_val .= '</td><td valign="middle" align="right">';
@@ -419,12 +421,11 @@ class cNav_bar
 
 
 $nav_bar_alias = new cNav_bar ($PALANG['pOverview_alias_title'], $fDisplay, $CONF['page_size'], $pagebrowser_alias, $search);
-$nav_bar_alias->url = '&amp;domain='.$fDomain;
+$nav_bar_alias->append_to_url = '&amp;domain='.$fDomain;
 
 $pagebrowser_mailbox = create_page_browser("$table_mailbox.username", $mailbox_pagebrowser_query);
 $nav_bar_mailbox = new cNav_bar ($PALANG['pOverview_mailbox_title'], $fDisplay, $CONF['page_size'], $pagebrowser_mailbox, $search);
-$nav_bar_mailbox->url = '&amp;domain='.$fDomain;
-//print $nav_bar_alias->display_top ();
+$nav_bar_mailbox->append_to_url = '&amp;domain='.$fDomain;
 
 
 // this is why we need a proper template layer.
@@ -451,8 +452,10 @@ $smarty->assign ('tDisplay_up_show', $tDisplay_up_show);
 $smarty->assign ('tDisplay_next_show', $tDisplay_next_show);
 $smarty->assign ('tDisplay_next', $tDisplay_next);
 
-$smarty->assign ('tAliasDomains', $tAliasDomains);
-$smarty->assign ('aliasdomain_data', $aliasdomain_data);
+if (Config::bool('alias_domain')) {
+    $smarty->assign ('tAliasDomains', $tAliasDomains);
+    $smarty->assign ('aliasdomain_data', $aliasdomain_data);
+}
 
 $smarty->assign ('tAlias', $tAlias);
 $smarty->assign ('alias_data', $alias_data);
