@@ -1,16 +1,16 @@
 <?php
-/** 
- * Postfix Admin 
- * 
- * LICENSE 
- * This source file is subject to the GPL license that is bundled with  
- * this package in the file LICENSE.TXT. 
- * 
- * Further details on the project are available at http://postfixadmin.sf.net 
- * 
- * @version $Id: setup.php 1855 2016-08-08 05:00:39Z gingerdog $ 
- * @license GNU GPL v2 or later. 
- * 
+/**
+ * Postfix Admin
+ *
+ * LICENSE
+ * This source file is subject to the GPL license that is bundled with
+ * this package in the file LICENSE.TXT.
+ *
+ * Further details on the project are available at http://postfixadmin.sf.net
+ *
+ * @version $Id$
+ * @license GNU GPL v2 or later.
+ *
  * File: setup.php
  * Used to help ensure a server is setup appropriately during installation/setup.
  * After setup, it should be renamed or removed.
@@ -54,16 +54,21 @@ $f_mb_encode_mimeheader = function_exists ("mb_encode_mimeheader");
 $f_imap_open = function_exists ("imap_open");
 
 $file_config = file_exists (realpath ("./config.inc.php"));
+$file_local_config = file_exists (realpath ("./config.local.php"));
 
 $error = 0;
 
+$errormsg = [];
+
 //
 // Check for PHP version
 //
+$phpversion = 'unknown-version';
+
 if ($f_phpversion == 1)
 {
     if (phpversion() < 5) {
-        print "<li><b>Error: Depends on: PHP v5</b><br /></li>\n";
+        print "<li><b>Error: Depends on: PHP v5+</b><br /></li>\n";
         $error += 1;
     } elseif (version_compare(phpversion(), '5.2.3') < 0) {
         # smarty uses htmlentities() with 4 parameters, the 4th parameter was introduced in PHP 5.2.3
@@ -110,7 +115,7 @@ if ($f_get_magic_quotes_gpc == 1)
     }
     else
     {
-        print "<li><b>Warning: Magic Quotes: ON (internal workaround used)</b></li>\n";   
+        print "<li><b>Warning: Magic Quotes: ON (internal workaround used)</b></li>\n";
     }
 }
 else
@@ -133,7 +138,7 @@ if ($file_config == 1)
             print "<li>Checking \$CONF['configured'] - OK\n";
         } else {
             print "<li><b>Warning: \$CONF['configured'] is 'false'.<br>\n";
-            print "You must edit your config.inc.php and change this to true (this indicates you've created the database and user)</b>\n";
+            print "You must edit your config.local.php and change this to true (this indicates you've created the database and user)</b>\n";
         }
     }
 }
@@ -147,24 +152,14 @@ else
 }
 
 //
-// Check if templates directory is writable
+// Check for config.local.php
 //
-
-if (!is_writeable($incpath.'/templates_c'))
-{
-    if(!is_dir($incpath . '/templates_c')) {
-        print "<li><b>Error: Smarty template compile directory templates_c not found.</b><br />\n";
-        echo "<b>Please <code>mkdir -p $incpath/templates_c</code> and make it writeable by the web server</b>\n";
-        $error =+ 1;
-    }
-    else {
-        print "<li><b>Error: Smarty template compile directory templates_c is not writable.</b><br />\n";
-        print "<b>Please make it writable.</b><br />\n";
-        print "<b>If you are using SELinux or AppArmor, you might need to adjust their setup to allow write access.</b><br />\n";
-        $error =+ 1;
-    }
+if ($file_local_config == 1) {
+    print "<li>Depends on: presence config.local.php - OK</li>\n";
 } else {
-	print "<li>Smarty template compile directory is writable - OK<br />\n";
+    print "<li><b>Warning: config.local.php - NOT FOUND</b><br /></li>\n";
+    print "It's Recommended to store your own settings in config.local.php instead of editing config.inc.php<br />";
+    print "Create the file, and edit as appropriate (e.g. select database type etc)<br />";
 }
 
 //
@@ -174,10 +169,10 @@ if (($f_mysql_connect == 0) and ($f_mysqli_connect == 0) and ($f_pg_connect == 0
 {
     print "<li><b>Error: There is no database support in your PHP setup</b><br />\n";
     print "To install MySQL 3.23 or 4.0 support on FreeBSD:<br />\n";
-    print "<pre>% cd /usr/ports/databases/php$phpversion-mysql/\n";
+    print "<pre>% cd /usr/ports/databases/php{$phpversion}-mysql/\n";
     print "% make clean install\n";
     print " - or with portupgrade -\n";
-    print "% portinstall php$phpversion-mysql</pre>\n";
+    print "% portinstall php{$phpversion}-mysql</pre>\n";
     if ($phpversion >= 5)
     {
         print "To install MySQL 4.1 support on FreeBSD:<br />\n";
@@ -187,10 +182,10 @@ if (($f_mysql_connect == 0) and ($f_mysqli_connect == 0) and ($f_pg_connect == 0
         print "% portinstall php5-mysqli</pre>\n";
     }
     print "To install PostgreSQL support on FreeBSD:<br />\n";
-    print "<pre>% cd /usr/ports/databases/php$phpversion-pgsql/\n";
+    print "<pre>% cd /usr/ports/databases/php{$phpversion}-pgsql/\n";
     print "% make clean install\n";
     print " - or with portupgrade -\n";
-    print "% portinstall php$phpversion-pgsql</pre></li>\n";
+    print "% portinstall php{$phpversion}-pgsql</pre></li>\n";
     $error =+ 1;
 }
 //
@@ -210,7 +205,7 @@ if ($phpversion >= 5)
     {
         print "<li>Depends on: MySQL 4.1 - OK\n";
         if ( !($config_loaded && $CONF['database_type'] == 'mysqli') ) {
-            print "<br>(change the database_type to 'mysqli' in config.inc.php if you want to use MySQL)\n";
+            print "<br>(change the database_type to 'mysqli' in config.local.php if you want to use MySQL)\n";
         }
         print "</li>";
     }
@@ -223,7 +218,7 @@ if ($f_pg_connect == 1)
 {
     print "<li>Depends on: PostgreSQL - OK \n";
     if ( !($config_loaded && $CONF['database_type'] == 'pgsql') ) {
-        print "<br>(change the database_type to 'pgsql' in config.inc.php if you want to use PostgreSQL)\n";
+        print "<br>(change the database_type to 'pgsql' in config.local.php if you want to use PostgreSQL)\n";
     }
     print "</li>";
 }
@@ -232,7 +227,7 @@ if ($f_sqlite_open == 1)
 {
     print "<li>Depends on: SQLite - OK \n";
     if ( !($config_loaded && db_sqlite()) ) {
-        print "<br>(change the database_type to 'sqlite' in config.inc.php if you want to use SQLite)\n";
+        print "<br>(change the database_type to 'sqlite' in config.local.php if you want to use SQLite)\n";
     }
     print "</li>";
 }
@@ -243,13 +238,13 @@ if ($f_sqlite_open == 1)
 if ($config_loaded) {
     list ($link, $error_text) = db_connect(TRUE);
     if ($error_text == "") {
-        print "<li>Testing database connection - OK - {$CONF['database_type']}://{$CONF['database_user']}:xxxxx@{$CONF['database_host']}/{$CONF['database_name']}</li>";
+        print "<li>Testing database connection (using {$CONF['database_type']}) - OK</li>";
     } else {
         print "<li><b>Error: Can't connect to database</b><br />\n";
-        print "Please edit the \$CONF['database_*'] parameters in config.inc.php.\n";
+        print "Please edit the \$CONF['database_*'] parameters in config.local.php.\n";
         print "$error_text</li>\n";
         $error ++;
-    } 
+    }
 }
 
 //
@@ -386,7 +381,7 @@ else
             }
 
         }
-    } 
+    }
 
     if ( ($setuppw == "" || $setuppw == "changeme" || safeget("lostpw") == 1 || $lostpw_error != 0) /* && $_SERVER['REQUEST_METHOD'] != "POST" */ ) {
 # show "create setup password" form
@@ -397,15 +392,16 @@ else
 <form name="setuppw" method="post" action="setup.php">
 <input type="hidden" name="form" value="setuppw" />
 <table>
+   <tr>
       <td colspan="3"><h3>Change setup password</h3></td>
    </tr>
    <tr>
-      <td>Setup password</td>
+      <td><label for="setup_password">Setup password</label></td>
       <td><input class="flat" type="password" name="setup_password" value="" /></td>
       <td></td>
    </tr>
    <tr>
-      <td>Setup password (again)</td>
+      <td><label for="setup_password2">Setup password (again)</label></td>
       <td><input class="flat" type="password" name="setup_password2" value="" /></td>
       <td></td>
    </tr>
@@ -429,24 +425,24 @@ else
       <td colspan="3"><h3>Create superadmin account</h3></td>
    </tr>
    <tr>
-      <td>Setup password</td>
-      <td><input class="flat" type="password" name="setup_password" value="" /></td>
+       <td><label for="setup_password">Setup password</label></td>
+      <td><input id=setup_password class="flat" type="password" name="setup_password" value="" /></td>
       <td><a href="setup.php?lostpw=1">Lost password?</a></td>
    </tr>
    <tr>
-      <td><?php print $PALANG['admin'] . ":"; ?></td>
-      <td><input class="flat" type="text" name="username" value="<?php print $tUsername; ?>" /></td>
-      <td><?php if (isset($errormsg['username'])) print $errormsg['username']; ?><?php print $PALANG['email_address'] ?></td>
+      <td><label for="username"><?php print $PALANG['admin'] . ":"; ?></label></td>
+      <td><input id="username" class="flat" type="text" name="username" value="<?php print $tUsername; ?>" /></td>
+      <td><?= _error_field($errormsg, 'username'); ?> <?php print $PALANG['email_address'] ?></td>
    </tr>
    <tr>
-      <td><?php print $PALANG['password'] . ":"; ?></td>
-      <td><input class="flat" type="password" name="password" /></td>
-      <td><?php if (isset($errormsg['password'])) print $errormsg['password']; ?></td>
+       <td><label for="password"><?php print $PALANG['password'] . ":"; ?></label></td>
+      <td><input id="password" class="flat" type="password" name="password" /></td>
+      <td><?= _error_field($errormsg, 'password'); ?></td>
    </tr>
    <tr>
-      <td><?php print $PALANG['password_again'] . ":"; ?></td>
-      <td><input class="flat" type="password" name="password2" /></td>
-      <td><?php if (isset($errormsg['password2'])) print $errormsg['password2']; ?></td>
+       <td><label for="password2"><?php print $PALANG['password_again'] . ":"; ?></label></td>
+      <td><input id="password2" class="flat" type="password" name="password2" /></td>
+      <td><?= _error_field($errormsg, 'password2'); ?></td>
    </tr>
    <tr>
       <td colspan="3" class="hlp_center"><input class="button" type="submit" name="submit" value="<?php print $PALANG['pAdminCreate_admin_button']; ?>" /></td>
@@ -457,9 +453,10 @@ else
 
 <?php
     }
-
-    print "<b>Since version 2.3 there is no requirement to delete setup.php!</b><br />\n";
-    print "<b>Check the config.inc.php file for any other settings that you might need to change!<br />\n";
+?>
+    <b>Since version 2.3 there is no requirement to delete setup.php!</b><br />
+    <b>Check the config.inc.php file for any other settings that you might need to change!<br />
+<?php
 }
 ?>
 </div>
@@ -467,6 +464,13 @@ else
 </html>
 <?php
 
+function _error_field($errors, $key) {
+    if(!isset($errors[$key])) {
+        return '';
+    }
+    return "<span style='color: red'>{$errors[$key]}</span>";
+}
+
 function generate_setup_password_salt() {
     $salt = time() . '*' . $_SERVER['REMOTE_ADDR'] . '*' . mt_rand(0,60000);
     $salt = md5($salt);
@@ -526,7 +530,7 @@ function create_admin($values) {
 
     if (!$handler->init($values['username'])) {
         return array(1, "", $handler->errormsg);
-    } 
+    }
 
     if (!$handler->set($values)) {
         return array(1, "", $handler->errormsg);
