@@ -14,7 +14,18 @@ class PFASmarty {
         //$this->template->debugging = true;
         $incpath = dirname(__FILE__);
         $this->template->setTemplateDir(dirname(__FILE__) . '/templates');
-        $this->template->setCompileDir(dirname(__FILE__) . '/templates_c');
+
+        // if it's not present or writeable, smarty should just not cache.
+        $templates_c = dirname(__FILE__) . '/templates_c';
+        if(is_dir($templates_c) && is_writeable($templates_c)) {
+            $this->template->setCompileDir($templates_c);
+        }
+        else {
+            # unfortunately there's no sane way to just disable compiling of templates
+            error_log("ERROR: directory $templates_c doesn't exist or isn't writeable for the webserver");
+            die("ERROR: the templates_c directory doesn't exist or isn't writeable for the webserver");
+        }
+
         $this->template->setConfigDir(dirname(__FILE__) . '/configs');
     }
 
