@@ -4,7 +4,7 @@ if(!defined('POSTFIXADMIN')) {
 }
 
 /* vim: set expandtab softtabstop=4 tabstop=4 shiftwidth=4: */
-# @version $Id: upgrade.php 1853 2016-05-22 19:58:54Z christian_boltz $ 
+# @version $Id$ 
 
 # Note: run with upgrade.php?debug=1 to see all SQL error messages
 
@@ -139,7 +139,7 @@ function _do_upgrade($current_version) {
 
     $target_version = 0;
     // Rather than being bound to an svn revision number, just look for the largest function name that matches upgrade_\d+...
-    // $target_version = preg_replace('/[^0-9]/', '', '$Revision: 1853 $');
+    // $target_version = preg_replace('/[^0-9]/', '', '$Revision$');
     $funclist = get_defined_functions();
     $our_upgrade_functions = array_filter($funclist['user'], '_upgrade_filter_function');
     foreach($our_upgrade_functions as $function_name) {
@@ -339,6 +339,14 @@ function _add_index($table, $indexname, $fieldlist) {
 }
 
 function upgrade_1_mysql() {
+    #
+    # creating the tables in this very old layout (pre 2.1) causes trouble if the MySQL charset is not latin1 (multibyte vs. index length)
+    # therefore:
+
+        return; # <-- skip running this function at all.
+
+    # (remove the above "return" if you really want to start with a pre-2.1 database layout)
+
     // CREATE MYSQL DATABASE TABLES.
     $admin = table_by_key('admin');
     $alias = table_by_key('alias');
@@ -438,6 +446,14 @@ function upgrade_1_mysql() {
 }
 
 function upgrade_2_mysql() {
+    #
+    # updating the tables in this very old layout (pre 2.1) causes trouble if the MySQL charset is not latin1 (multibyte vs. index length)
+    # therefore:
+
+        return; # <-- skip running this function at all.
+
+    # (remove the above "return" if you really want to update a pre-2.1 database)
+
     # upgrade pre-2.1 database
     # from TABLE_BACKUP_MX.TXT
     $table_domain = table_by_key ('domain');
@@ -576,6 +592,14 @@ function upgrade_2_pgsql() {
 }
 
 function upgrade_3_mysql() {
+    #
+    # updating the tables in this very old layout (pre 2.1) causes trouble if the MySQL charset is not latin1 (multibyte vs. index length)
+    # therefore:
+
+        return; # <-- skip running this function at all.
+
+    # (remove the above "return" if you really want to update a pre-2.1 database)
+
     # upgrade pre-2.1 database
     # from TABLE_CHANGES.TXT
     $table_admin = table_by_key ('admin');
@@ -907,7 +931,7 @@ function upgrade_318_mysql() {
     db_query_parsed( "
         CREATE TABLE {IF_NOT_EXISTS} $table_vacation_notification (
             on_vacation varchar(255) {LATIN1} NOT NULL,
-            notified varchar(255) NOT NULL,
+            notified varchar(255) {LATIN1} NOT NULL,
             notified_at timestamp NOT NULL default CURRENT_TIMESTAMP,
             PRIMARY KEY on_vacation (`on_vacation`, `notified`),
         CONSTRAINT `vacation_notification_pkey` 
@@ -919,7 +943,7 @@ function upgrade_318_mysql() {
 
     # in case someone has manually created the table with utf8 fields before:
     $all_sql = explode("\n", trim("
-        ALTER TABLE `$table_vacation_notification` CHANGE `notified`    `notified`    VARCHAR( 255 ) NOT NULL
+        ALTER TABLE `$table_vacation_notification` CHANGE `notified`    `notified`    VARCHAR( 255 ) {LATIN1} NOT NULL
         ALTER TABLE `$table_vacation_notification` DEFAULT CHARACTER SET utf8
     "));
     # Possible errors that can be ignored:
@@ -1009,8 +1033,8 @@ function upgrade_438_mysql() {
     $table_alias_domain = table_by_key('alias_domain');
     db_query_parsed("
         CREATE TABLE IF NOT EXISTS $table_alias_domain (
-            `alias_domain` varchar(255) NOT NULL default '',
-            `target_domain` varchar(255) NOT NULL default '',
+            `alias_domain` varchar(255) {LATIN1} NOT NULL default '',
+            `target_domain` varchar(255) {LATIN1} NOT NULL default '',
             `created` {DATETIME},
             `modified` {DATETIME},
             `active` tinyint(1) NOT NULL default '1',
@@ -1619,20 +1643,35 @@ function upgrade_1824_sqlite() {
 function upgrade_1835_mysql() {
     # change default values for existing datetime fields with a 0000-00-00 default to {DATETIME}
 
-    foreach (array('admin', 'alias', 'alias_domain', 'domain', 'mailbox', 'domain_admins', 'vacation') as $table_to_change) {
+    foreach (array('domain_admins', 'vacation') as $table_to_change) {
         $table = table_by_key($table_to_change);
         db_query_parsed("ALTER TABLE `$table` CHANGE `created` `created` {DATETIME}");
     }
 
     foreach (array('admin', 'alias', 'alias_domain', 'domain', 'mailbox') as $table_to_change) {
         $table = table_by_key($table_to_change);
-        db_query_parsed("ALTER TABLE `$table` CHANGE `modified` `modified` {DATETIME}");
+        db_query_parsed("ALTER TABLE `$table` CHANGE `created` `created` {DATETIME}, CHANGE `modified` `modified` {DATETIME}");
     }
 
     $table = table_by_key('log');
     db_query_parsed("ALTER TABLE `$table` CHANGE `timestamp` `timestamp` {DATETIME}");
 }
 
+function upgrade_1836_mysql() {
+    $table_alias_domain = table_by_key ('alias_domain');
+    $table_vacation_notification = table_by_key('vacation_notification');
+
+    $all_sql = explode("\n", trim("
+        ALTER TABLE `$table_alias_domain`          CHANGE `alias_domain`    `alias_domain`  VARCHAR(255) {LATIN1} NOT NULL default ''
+        ALTER TABLE `$table_alias_domain`          CHANGE `target_domain`   `target_domain` VARCHAR(255) {LATIN1} NOT NULL default ''
+        ALTER TABLE `$table_vacation_notification` CHANGE `notified`        `notified`      VARCHAR(255) {LATIN1} NOT NULL default ''
+    "));
+
+    foreach ($all_sql as $sql) {
+        $result = db_query_parsed($sql, TRUE);
+    }
+
+}
 # TODO MySQL:
 # - various varchar fields do not have a default value
 #   https://sourceforge.net/projects/postfixadmin/forums/forum/676076/topic/3419725
